var RnaQcAliquot = function()
{
	var rnaqc = {};
	
	var HISENSE_LIMIT = 50.0;
	var ALIQUOT_VOLUME_NORMAL = 2.0;
	var ALIQUOT_VOLUME_HISENSE = 6.0;
	var ALIQUOT_VOLUME_BA = 1.0;
	
	var selectedRna;
	var selectedBioPlate;
	var subtypeRna = null;
	var bioPlateNameIsValid = false;
	var bioPlateIsValid = false;
	
	var autoGoNext = 0;
	var newRna = [];
	
	// Page initialization
	rnaqc.initPage = function()
	{
		// Step 1
		Events.addEventHandler('step-1', 'wizard-validate', rnaqc.validateStep1);
		Buttons.addClickHandler('btnSelectRna', rnaqc.selectRna);
		Events.addEventHandler('rna', 'base-selected', rnaqc.onRnaSelected);
		
		// Step 2
		Events.addEventHandler('step-2', 'wizard-initialize', rnaqc.initializeStep2);
		Events.addEventHandler('step-2', 'wizard-validate', rnaqc.validateStep2);
		Events.addEventHandler('bioPlates', 'change', rnaqc.bioPlateOnChange);
		Events.addEventHandler('CALIPER_RNAQC', 'click', rnaqc.bioPlateTypeOnChange);
		Events.addEventHandler('BA_RNAQC', 'click', rnaqc.bioPlateTypeOnChange);
		Events.addEventHandler('bioPlateName', 'change', rnaqc.bioPlateNameOnChange);

		// Step 3
		Events.addEventHandler('step-3', 'wizard-initialize', rnaqc.initializeStep3);
		Events.addEventHandler('step-3', 'wizard-validate', rnaqc.validateStep3);
		
		// Navigation
		Buttons.addClickHandler('gocancel', Wizard.cancelWizard);
		Buttons.addClickHandler('gorestart', Wizard.restartWizard);
		Buttons.addClickHandler('gonext', Wizard.goNextOnClick);
		Buttons.addClickHandler('goregister', Wizard.goRegister);
		Buttons.addClickHandler('goprint', rnaqc.printVersion);

		// Final registration
		Events.addEventHandler('wizard', 'wizard-submit', rnaqc.submit);

		var rna = Data.json('page-data', 'rna-id');
		if (rna.length > 0)
		{
			Doc.show('step-1');
			autoGoNext = rna.length;
			// Get more information about the selected rna
			var url = '../RnaQc.servlet?ID='+App.getSessionId();
			url += '&cmd=GetRnaInfo&rnaIds=' + rna.join(',');
			Wizard.asyncJsonRequest(url, rnaqc.onRnaInfoLoaded);
		}
		else
		{
			var url = '../RnaQc.servlet?ID='+App.getSessionId();
			url += '&cmd=GetRnaExtractsWithoutQc';
			Wizard.showLoadingAnimation('Loading RNA extracts...');
			Wizard.asyncJsonRequest(url, rnaqc.onRnaLoaded);
		}
	}
	
	rnaqc.onRnaLoaded = function(response)
	{
		var frm = document.forms['reggie'];
		var rnaExtracts = response.rnaExtracts;
		
		if (rnaExtracts.length > 0)
		{
			for (var i=0; i < rnaExtracts.length; i++)
			{
				var selected = i < 12;
				var rna = rnaExtracts[i];
				rnaqc.addRnaOption(frm.rna, rna, selected);
			}
		}
		else
		{	
			Wizard.setInputStatus('rna', 'invalid', 'No RNA available for quality control.');
		}
		
		Doc.show('step-1');
		Doc.show('gonext');
	}
	
	rnaqc.selectRna = function()
	{
		var frm = document.forms['reggie'];
		if (frm.rna.disabled) return;
		
		if (subtypeRna == null)
		{
			subtypeRna = Reggie.getSubtypeInfo('RNA');
		}
		
		newRna = [];
		var url = '&resetTemporary=1';
		url += '&tmpfilter:INT:itemSubtype='+subtypeRna.id;
		Dialogs.selectItem('EXTRACT', 'rna', 1, url);
	}

	rnaqc.onRnaSelected = function(event)
	{
		var rna = event.detail;
		
		var frm = document.forms['reggie'];
		var rnaList = frm.rna;
		var isNew = true;
		for (var i = 0; i < rnaList.length; i++)
		{
			if (rnaList[i].value == rna.id)
			{
				rnaList[i].selected = true;
				isNew = false;
			}
		}
		
		if (isNew) newRna[newRna.length] = rna.id;
		
		if (event.detail.remaining == 0 && newRna.length > 0)
		{
			// Get more information about the selected rna
			var url = '../RnaQc.servlet?ID='+App.getSessionId();
			url += '&cmd=GetRnaInfo&rnaIds=' + newRna.join(',');
			Wizard.asyncJsonRequest(url, rnaqc.onRnaInfoLoaded);
		}
	}

	rnaqc.onRnaInfoLoaded = function(response)
	{
		var frm = document.forms['reggie'];
		var rnaList = response.rna;

		for (var rnaNo = 0; rnaNo < rnaList.length; rnaNo++)
		{
			var rna = rnaList[rnaNo];
			rnaqc.addRnaOption(frm.rna, rna, true);
		}
		
		if (frm.rna.length == autoGoNext)
		{
			Wizard.goNext(true);
		}
	}
	
	rnaqc.addRnaOption = function(list, rna, selected)
	{
		var name = rna.name;
		if (rna.bioWell)
		{
			name += ' -- ' + rna.bioWell.bioPlate.name + ' (' + Reggie.wellToAlpha(rna.bioWell.row)+(rna.bioWell.column+1)+')';
		}

		var option = new Option(name, rna.id, selected, selected);
		if (rna.specimen && rna.specimen.YellowLabel != null) option.className = 'yellow';
		option.rna = rna;
		list[list.length] = option;
	}
	
	rnaqc.validateStep1 = function(event)
	{
		var frm = document.forms['reggie'];
		var rnaList = frm.rna;
		
		selectedRna = [];
		for (var i=0; i < rnaList.length; i++)
		{
			if (rnaList[i].selected)
			{
				selectedRna[selectedRna.length] = rnaList[i].rna;
			}
		}
			
		if (selectedRna.length == 0)
		{
			Wizard.setInputStatus('rna', 'invalid', 'Not selected', 'invalid');
			event.preventDefault();
		}
		else
		{
			Wizard.setInputStatus('rna', 'valid');
		}
	}

	rnaqc.initializeStep2 = function()
	{
		var frm = document.forms['reggie'];
		Wizard.setCurrentStep(2);
		Doc.show('gonext');
		Doc.show('gocancel');
		
		Reggie.loadProtocols('QUALITY_CONTROL', 'protocols');

		var url = '../RnaQc.servlet?ID='+App.getSessionId();
		url += '&cmd=GetActiveRnaQcBioPlates&numFreeWells=' + selectedRna.length;
		Doc.addClass('bioPlates', 'list-loading');
		frm.bioPlates[0] = new Option('loading...');
		Wizard.asyncJsonRequest(url, rnaqc.bioPlatesLoaded);
	}
	
	rnaqc.bioPlatesLoaded = function(response)
	{
		var frm = document.forms['reggie'];
		frm.bioPlates.length = 0;
		Doc.removeClass('bioPlates', 'list-loading');

		var plates = response.plates;
		var hasSelected = false;
		for (var i = 0; i < plates.length; i++)
		{
			var plate = plates[i];
			var selected = !hasSelected && plate.freeWells >= selectedRna.length;
			hasSelected |= selected;
			var option = new Option(plate.name + ' -- ' + plate.freeWells + ' free wells', plate.id, selected);
			option.plate = plate;
			frm.bioPlates[frm.bioPlates.length] = option;
		}
		frm.bioPlates[frm.bioPlates.length] = new Option('- create new -', 0, !hasSelected);
	
		rnaqc.bioPlateOnChange();
		frm.bioPlates.focus();
	}
	
	// If the 'create new' option is selected we need to display that section
	rnaqc.bioPlateOnChange = function()
	{
		var frm = document.forms['reggie'];
		
		var createNewSelected = parseInt(frm.bioPlates.value) == 0;
		Doc.showHide('createNewBioPlateSection', createNewSelected);
		
		Wizard.setInputStatus('bioPlates');
		bioPlateIsValid = true;
		
		if (createNewSelected)
		{
			if (frm.bioPlateName.value == '') 
			{
				rnaqc.bioPlateTypeOnChange();
			}
			frm.bioPlateBarcode.focus();
		}
		else
		{
			var selected = frm.bioPlates[frm.bioPlates.selectedIndex].plate;
			if (selected.freeWells < selectedRna.length)
			{
				Wizard.setInputStatus('bioPlates', 'invalid', 'Not enough free wells');
				bioPlateIsValid = false;
			}
		}
	}

	//	We need to get the next auto-generated name for a new CaliperPlate or BAPlate
	rnaqc.bioPlateTypeOnChange = function()
	{
		var frm = document.forms['reggie'];
		var selectedType = Forms.getCheckedRadio(frm.bioPlateType);
		if (selectedType.nextPlateName)
		{
			rnaqc.onNextPlateNameGenerated();
		}
		else
		{
			var url = '../RnaQc.servlet?ID='+App.getSessionId();
			url += '&cmd=GetNextAutoGeneratedPlateName&bioPlateType=' + selectedType.value;
			Wizard.asyncJsonRequest(url, rnaqc.onNextPlateNameGenerated);
		}
	}

	rnaqc.onNextPlateNameGenerated = function(response)
	{
		var frm = document.forms['reggie'];
		var selectedType = Forms.getCheckedRadio(frm.bioPlateType);
		if (response)
		{
			selectedType.nextPlateName = response.nextPlateName;
		}
		
		frm.bioPlateName.value = selectedType.nextPlateName;
		rnaqc.bioPlateNameOnChange();
	}

	rnaqc.bioPlateNameOnChange = function()
	{
		var frm = document.forms['reggie'];
		
		var bioPlateName = frm.bioPlateName.value;
		bioPlateNameIsValid = false;
		if (bioPlateName == '')
		{
			Wizard.setInputStatus('bioPlateName', 'invalid', 'Missing');
			return;
		}
		
		bioPlateNameIsValid = true;
		if (bioPlateName.indexOf('CaliperPlate') != 0 && bioPlateName.indexOf('BAPlate') != 0)
		{
			Wizard.setInputStatus('bioPlateName', 'warning', 'Should start with <i>CaliperPlate</code> or <i>BAPlate</i>.');
			return;
		}

		Wizard.setInputStatus('bioPlateName', 'valid');
	}
	
	rnaqc.validateStep2 = function(event)
	{
		var frm = document.forms['reggie'];
		var bioPlateId = parseInt(frm.bioPlates.value);
		if (!bioPlateIsValid || (bioPlateId == 0 && !bioPlateNameIsValid))
		{
			event.preventDefault();
		}
	}

	rnaqc.initializeStep3 = function()
	{
		var frm = document.forms['reggie'];
		var bioPlateId = parseInt(frm.bioPlates.value);
		
		var url = '../RnaQc.servlet?ID='+App.getSessionId();
		url += '&cmd=GetFreeWellsInfo&bioPlateId='+bioPlateId;
		if (bioPlateId == 0)
		{
			url += '&bioPlateType=' + Forms.getCheckedRadio(frm.bioPlateType).value;
		}
		url += '&numAliquots='+selectedRna.length;
		Wizard.showLoadingAnimation('Loading information about free wells...');
		Wizard.asyncJsonRequest(url, rnaqc.freeWellsLoaded);
	}
	
	rnaqc.freeWellsLoaded = function(response)
	{
		var frm = document.forms['reggie'];

		selectedBioPlate = response.bioPlate;
		if (selectedBioPlate.id == 0)
		{
			selectedBioPlate.name = frm.bioPlateName.value;
			selectedBioPlate.barcode = frm.bioPlateBarcode.value;
		}
		var isCaliper = Doc.element('CALIPER_RNAQC').checked;
		
		var html = '<table id="rnaQcTable" class="step-form">';
		html += '<thead class="bg-filled-100">';
		// First header row
		html += '<tr>';
		html += '<th>RNA QC</th>';
		html += '<th class="dottedleft">Storage</th>';
		html += '<th colspan="2" class="dottedleft">' + Strings.encodeTags(selectedBioPlate.name) + '</th>';
		html += '<th class="dottedleft">HiSense</th>';
		html += '<th>Volume</th>';
		html += '<th>NDConc</th>';
		html += '<th></th>';
		html += '<th class="dottedleft"></th>';
		html += '</tr>';
		// Second header row
		html += '<tr>';
		html += '<th></th>';
		html += '<th class="dottedleft">box</th>';
		html += '<th class="dottedleft">Row</th>';
		html += '<th>Column</th>';
		html += '<th class="dottedleft">NDConc ‹ ' + HISENSE_LIMIT + '</th>';
		html += '<th>(µl)</th>';
		html += '<th>(ng/µl)</th>';
		html += '<th></th>';
		html += '<th class="dottedleft">Comments</th>';
		html += '</tr>';
		html += '</thead>';
		html += '<tbody>';
		
		var homeUrl = Data.get('page-data', 'home-url');
		var yellowImg = '<img src="'+homeUrl+'/images/yellow-label.png">';
		for (var i=0; i < selectedRna.length; i++)
		{
			var rna = selectedRna[i];
			var isYellow = rna.specimen && rna.specimen.YellowLabel != null;
			rna.isValid = false;
			rna.isValidVolume = true;
			
			var hiSenseChecked = '';
			var hiSenseDisabled = isCaliper ? '' : ' disabled';
			var ndConc = null;
			var volume = isCaliper ? ALIQUOT_VOLUME_NORMAL : ALIQUOT_VOLUME_BA;
			if (rna.NDConc)
			{
				ndConc = rna.NDConc;
				if (isCaliper && ndConc < HISENSE_LIMIT)
				{
					hiSenseChecked = ' checked';
					volume = ALIQUOT_VOLUME_HISENSE;
				}
			}

			var img = isYellow ? yellowImg : '';
			html += '<tr class="highlight'+(isYellow ? ' yellow-specimen' : '')+'">';
			html += '<td class="rna if-yellow">'+img+Strings.encodeTags(rna.nextRnaQcName)+'</td>';
			html += '<td class="location dottedleft">'+Strings.encodeTags(rna.bioWell.bioPlate.name + ' ' + rna.bioWell.location)+'</td>';
			html += '<td class="dottedleft">';
			html += '<input name="row.'+i+'" id="row.'+i+'" type="text" class="required" style="width: 3em; text-transform:uppercase;" maxlength="2"></td>';
			html += '<td><input name="column.'+i+'" id="column.'+i+'" type="text" class="required" style="width: 3em;" maxlength="3"></td>';
			html += '<td class="dottedleft"><input name="hiSense.'+i+'" id="hiSense.'+i+'" type="checkbox" value="1" ' + hiSenseChecked + hiSenseDisabled +'></td>';
			html += '<td>';
			html += '<input name="volume.'+i+'" id="volume.'+i+'" type="text" class="required" style="width: 3em;" maxlength="3" value="'+volume+'">';
			html += '</td>';
			html += '<td class="ndconc">';
			if (ndConc) html += Reggie.formatNumber(ndConc);
			html += '</td>';
			html += '<td class="status" id="well.'+i+'.status"></td>';
			html += '<td class="remarks help dottedleft"><span id="well.'+i+'.message" class="message"></span></td>';
			html += '</tr>';
		}
		html += '</tbody>';
		html += '</table>';
		
		Doc.element('rnaQc').innerHTML = html;
		Wizard.setCurrentStep(3);
		Doc.show('goregister');
		Doc.show('goprint');
		Doc.show('gocancel');
		Wizard.showGoNextConfirmation(true, 'Print the lab protocol before continuing with the registration!');

		if (selectedRna.length > 12) Doc.addClass('step-3', 'auto-hide');
		Wizard.keepSessionAlive();

		for (var i=0; i < selectedRna.length; i++)
		{
			Events.addEventHandler('row.'+i, 'keypress', Wizard.focusOnEnter, { 'next-focus': 'column.'+i });
			Events.addEventHandler('column.'+i, 'keypress', Wizard.focusOnEnter, { 'next-focus': 'volume.'+i });
			Events.addEventHandler('volume.'+i, 'keypress', Wizard.focusOnEnter, { 'next-focus': 'row.'+(i+1) });
			Events.addEventHandler('volume.'+i, 'keypress', Numbers.numberOnly);

			Events.addEventHandler('row.'+i, 'focus', rnaqc.wellOnFocus);
			Events.addEventHandler('row.'+i, 'change', rnaqc.wellOnChange, { 'index': i });
			Events.addEventHandler('column.'+i, 'change', rnaqc.wellOnChange, { 'index': i });
			Events.addEventHandler('volume.'+i, 'change', rnaqc.wellOnChange, { 'index': i });
			Events.addEventHandler('hiSense.'+i, 'click', rnaqc.hiSenseOnClick, { 'index': i });
			
			rnaqc.suggestWell(i);
		}
		
		frm['row.'+0].focus();
	}

	rnaqc.wellOnFocus = function(event)
	{
		var frm = document.forms['reggie'];
		
		var index = Data.int(event.currentTarget, 'index');
		var row = frm['row.'+index].value;
		var column = frm['column.'+index].value;
		
		if (row == '' && column == '') 
		{
			rnaqc.suggestWell(index);
		}
	}
	
	rnaqc.suggestWell = function(index)
	{
		var frm = document.forms['reggie'];
		if (frm['row.'+index].disabled) return;
		
		var bioWells = selectedBioPlate.bioWells;
		
		// First, map out the wells already used in the form
		var used = [];
		for (var i = 0; i < selectedRna.length; i++)
		{
			var rna = selectedRna[i];
			if (rna.isValid)
			{
				var row = frm['row.'+i].value.toUpperCase();
				var column = frm['column.'+i].value;
				var key = row+column;
				used[key] = true;
			}
		}
		
		// Find first unused well not followed by any used well
		var lastUnused = -1;
		for (var i = 0; i < bioWells.length; i++)
		{
			var well = bioWells[i];
			var row = Reggie.wellToAlpha(well.row);
			var column = well.column+1;
			var isUsed = used[row+column];
			
			if (well.canAdd && !isUsed && lastUnused == -1)
			{
				lastUnused = i;
			}
			else if (!well.canAdd || isUsed)
			{
				lastUnused = -1;
			}
		}
		
		if (lastUnused >= 0)
		{
			var well = bioWells[lastUnused];
			frm['row.'+index].value = Reggie.wellToAlpha(well.row);
			frm['column.'+index].value = well.column+1;
			
			Wizard.setInputStatus('well.'+index, 'valid');
			selectedRna[index].isValid = true;
		}
	}
	
	rnaqc.wellOnChange = function(event)
	{
		var frm = document.forms['reggie'];

		var index = Data.int(event.currentTarget, 'index');
		var row = frm['row.'+index].value;
		var column = frm['column.'+index].value;
		var volume = frm['volume.'+index].value;
		
		selectedRna[index].isValid = false;
		selectedRna[index].isValidVolume = false;
		
		if (row == '' || column == '')
		{
			Wizard.setInputStatus('well.'+index, 'invalid', 'Missing row or column');
			return;
		}
		
		if (volume == '')
		{
			Wizard.setInputStatus('well.'+index, 'invalid', 'Missing volume');
			return;
		}
		else if (parseFloat(volume) <= 0 || isNaN(parseFloat(volume)))
		{
			Wizard.setInputStatus('well.'+index, 'invalid', 'Volume must be &gt; 0');
			return;
		}
		selectedRna[index].isValidVolume = true;
		
		var rowC = Reggie.alphaToWell(row);
		if (rowC < 0 || rowC >= selectedBioPlate.geometry.rows)
		{
			setInputStatus('well.'+index, 'invalid', 'Row must be between A-' + Reggie.wellToAlpha(selectedBioPlate.geometry.rows-1));
			return;
		}
		
		var colC = parseInt(column, 10)-1;
		if (isNaN(colC) || colC < 0 || colC >= selectedBioPlate.geometry.columns)
		{
			Wizard.setInputStatus('well.'+index, 'invalid', 'Column must be between 1-' + selectedBioPlate.geometry.columns);
			return;
		}
		
		// Find the selected well
		var well = rnaqc.getWellByCoordinate(selectedBioPlate, rowC, colC);
		
		// Check that it is not already used
		if (!well.canAdd)
		{
			Wizard.setInputStatus('well.'+index, 'invalid', 'The selected well is already used');
			return;
		}
		
		// Seems to be ok
		Wizard.setInputStatus('well.'+index, 'valid');
		selectedRna[index].isValid = true;
		
		// The final check is a duplication check
		rnaqc.duplicateWellCheck();
	}

	//	Get a well from a plate given a coordinate.
	rnaqc.getWellByCoordinate = function(bioPlate, row, col)
	{
		for (var i = 0; i < bioPlate.bioWells.length; i++)
		{
			var w = bioPlate.bioWells[i];
			if (w.row == row && w.column == col)
			{
				return w;
			}
		}
		return null;
	}

	rnaqc.duplicateWellCheck = function()
	{
		var frm = document.forms['reggie'];
		var used = [];
		var index = [];
		
		for (var i = 0; i < selectedRna.length; i++)
		{
			var rna = selectedRna[i];

			if (rna.isValid)
			{
				var row = frm['row.'+i].value.toUpperCase();
				var column = frm['column.'+i].value;

				var key = row+column;
				var dupRna = used[key];
				if (dupRna)
				{
					Wizard.setInputStatus('well.'+i, 'invalid', dupRna.nextRnaQcName + ' is using the same well');
					Wizard.setInputStatus('well.'+index[key], 'invalid', rna.nextRnaQcName + ' is using the same well');
					rna.isDuplicate = true;
					dupRna.isDuplicate = true;
				}
				else
				{
					rna.isDuplicate = false;
					Wizard.setInputStatus('well.'+i, 'valid');
				}
				used[key] = rna;
				index[key] = i;
			}
		}
	}
	
	rnaqc.hiSenseOnClick = function(event)
	{
		var frm = document.forms['reggie'];
		var index = Data.int(event.currentTarget, 'index');
		var hiSenseChecked = event.currentTarget.checked;
		
		var volume = parseFloat(frm['volume.'+index].value);
		// Switch default volume when HiSense is toggled (unless the volume has been modified)
		if (volume == (hiSenseChecked ? ALIQUOT_VOLUME_NORMAL : ALIQUOT_VOLUME_HISENSE))
		{
			frm['volume.'+index].value = hiSenseChecked ? ALIQUOT_VOLUME_HISENSE : ALIQUOT_VOLUME_NORMAL;
			Events.sendChangeEvent(frm['volume.'+index]);
		}
		
	}
	
	rnaqc.printVersion = function()
	{
		Wizard.hideGoNextConfirmation();
		Doc.removeClass('gonext', 'disabled');
		var frm = document.forms['reggie'];
		var reportName = 'RNAQC Aliquot Protocol';
		var printNote = '<b>Note!</b> For better printing set page orientation to <i>portrait</i>.';
		Reggie.openPrintWindow('full-protocol', reportName, 'portrait', printNote, '../', 'rnaqc_aliquot.css');
	}
	
	rnaqc.validateStep3 = function(event)
	{
		var frm = document.forms['reggie'];

		// Check that no wells have an error or is duplicated
		for (var i = 0; i < selectedRna.length; i++)
		{
			var rna = selectedRna[i];
			if (!rna.isValid || rna.isDuplicate)
			{
				event.preventDefault();
				// Focus on the 'row' or 'volume' field
				frm[(rna.isValidVolume ? 'row.' : 'volume.')+i].focus();
				return;
			}
		}
	}

	rnaqc.submit = function()
	{
		var frm = document.forms['reggie'];
		
		var submitInfo = {};
		selectedBioPlate.bioWells = null;
		submitInfo.bioplate = selectedBioPlate;
		
		submitInfo.protocol = parseInt(frm.protocols.value, 10);
		
		var rnaQcExtracts = [];
		for (var i=0; i < selectedRna.length; i++)
		{
			var rnaQc = {};
			rnaQc.parentId = selectedRna[i].id;
			rnaQc.name = selectedRna[i].nextRnaQcName;
			rnaQc.row = frm['row.'+i].value;
			rnaQc.column = frm['column.'+i].value;
			rnaQc.QCHiSense = frm['hiSense.'+i].checked ? true : false;
			rnaQc.volume = parseFloat(frm['volume.'+i].value);
			rnaQcExtracts[rnaQcExtracts.length] = rnaQc;
		}
		submitInfo.rnaQcExtracts = rnaQcExtracts;

		var url = '../RnaQc.servlet?ID='+App.getSessionId();
		url += '&cmd=PlaceRnaQcAliquots';
		Wizard.showLoadingAnimation('Performing registration...');
		Wizard.asyncJsonRequest(url, rnaqc.submissionResults, 'POST', JSON.stringify(submitInfo));
	}

	rnaqc.submissionResults = function(response)
	{
		Wizard.showFinalMessage(response.messages);
		Doc.show('gorestart');
	}

	return rnaqc;
}();

Doc.onLoad(RnaQcAliquot.initPage);

